/**                                                                             
 * Set of utilities to provide details about the system and browser properties. 
 *                                                                              
 * Copyright 2005-2007 CSI International                                        
 * All rights reserved.                                                         
 *                                                                              
 * filename: BRWSRENV.js                                                        
 * version:  1.0, P. McClain, 20050804, Initial version.                        
 *	       2.0, P. McClain, 20070912, Major rewrite.  Modified API, enhanced     
 *                browser detection algorithm , added support for major         
 *			version numbers and browser groups.                                        
 */                                                                             
                                                                                
//--+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
                                                                                
/**                                                                             
 * Qualifier for CSI classes.                                                   
 */                                                                             
                                                                                
if (typeof CSI == 'undefined') CSI = function() {}                              
                                                                                
CSI.System = (function() {                                                      
	var _aDefinitions = [                                                          
		{name:"Safari", group:"AppleWebKit",                                          
		 browser:[{property:navigator.vendor, find:"Apple Computer, Inc."},           
		          {property:navigator.userAgent, find:"Safari/"}                      
		 ], version:[{property:navigator.userAgent, find:"Version/"},                 
			{property:navigator.userAgent, find:"Safari/"}	                              
		 ]},                                                                          
				                                                                            
		{name:"OmniWeb", group:"AppleWebKit",                                         
		 browser:[{property:navigator.userAgent, find:"AppleWebKit/"},                
		          {property:navigator.userAgent, find:"OmniWeb/"}                     
		 ], version:[{property:navigator.userAgent, find:"OmniWeb/"}]},               
                                                                                
		{name:"Konqueror", group:"Konqueror",                                         
		 browser:[{property:navigator.userAgent, find:"Konqueror/"}                   
		 ], version:[{property:navigator.userAgent, find:"Konqueror/"}]},             
                                                                                
		{name:"Opera", group:"Opera",                                                 
		 browser:[{property:window.opera }                                            
		 ], version:[{property:navigator.userAgent, find:"Opera/"},                   
			{property:navigator.userAgent, find:"Opera "}	                               
		 ]},                                                                          
                                                                                
		{name:"Epiphany", group:"Mozilla/Gecko",                                      
		 browser:[{property:navigator.userAgent, find:"Epiphany/" }                   
		 ], version:[{property:navigator.userAgent, find:"Epiphany/"}]},              
                                                                                
		{name:"Camino", group:"Mozilla/Gecko",                                        
		 browser:[{property:navigator.vendor, find:"Camino"},                         
		          {property:navigator.userAgent, find:"Camino/"}                      
		 ], version:[{property:navigator.userAgent, find:"Camino/"}]},                
                                                                                
		{name:"SeaMonkey", group:"Mozilla/Gecko",                                     
		 browser:[{property:navigator.userAgent, find:"SeaMonkey/"}                   
		 ], version:[{property:navigator.userAgent, find:"SeaMonkey/"}]},             
                                                                                
		{name:"Netscape", group:"Mozilla/Gecko",                                      
		 browser:[{property:navigator.userAgent, find:"Navigator/"}                   
		 ], version:[{property:navigator.userAgent, find:"Navigator/"}]},             
                                                                                
		{name:"Netscape", group:"Mozilla/Gecko",                                      
		 browser:[{property:navigator.userAgent, find:"Netscape/" }                   
		 ], version:[{property:navigator.userAgent, find:"Netscape/"}]},              
                                                                                
		{name:"Netscape", group:"Mozilla/Gecko",                                      
		 browser:[{property:navigator.userAgent, find:"Netscape6/"}                   
		 ], version:[{property:navigator.userAgent, find:"Netscape6/"}]},             
                                                                                
		{name:"Firefox", group:"Mozilla/Gecko",                                       
		 browser:[{property:navigator.userAgent, find:"Firefox/" }                    
		 ], version:[{property:navigator.userAgent, find:"Firefox/"}]},               
	                                                                               
		{name:"Internet Explorer", group:"Internet Explorer",                         
		 browser:[{property:navigator.appName, find:"Internet Explorer"},             
		          {property:navigator.userAgent, find:"MSIE" }                        
		 ], version:[{property:navigator.userAgent, find:"MSIE "}]},                  
                                                                                
		{name:"Mozilla", group:"Mozilla/Gecko",                                       
		 browser:[{property:navigator.userAgent, find:"Gecko/"}                       
		 ], version:[{property:navigator.userAgent, find:"rv:"}]},                    
                                                                                
		{name:"Netscape", group:"Mozilla",                                            
		 browser:[{property:navigator.userAgent, find:"Mozilla/"}                     
		 ], version:[{property:navigator.userAgent, find:"Mozilla/"}]}                
	];                                                                             
	                                                                               
	var _sBrowserVersion = null;                                                   
	var _sBrowserName = null;                                                      
	var _sBrowserGroup = null;                                                     
	var _sOS = null;                                                               
                                                                                
	function constructor() {                                                       
		this.get = function(property) {                                               
			if (property == 'browser-name') {                                            
				if (_sBrowserName == null) detect();                                        
				return _sBrowserName;                                                       
			} else if (property == 'browser-group') {                                    
				if (_sBrowserGroup == null) detect();                                       
				return _sBrowserGroup;	                                                     
			} else if (property == 'browser-version') {                                  
				if (_sBrowserVersion == null) detect();                                     
				return _sBrowserVersion;	                                                   
			} else if (property == 'browser-version-major') {                            
				if (_sBrowserVersion == null) detect();                                     
				if (_sBrowserVersion == "Unsupported") return -1;                           
				var major = _sBrowserVersion.replace(/[^\d\.]+/g, '_');                     
				major = parseInt(major.split('.')[0]);                                      
				if (major.length == 0 || isNaN(major)) return -1;                           
				return major;	                                                              
			} else if (property == 'operating-system') {                                 
				if (_sOS == null) detectOS();                                               
				return _sOS;                                                                
			} else					                                                                  
				return null;                                                                
                                                                                
			// Properties to be added in the future:                                     
			// browser-version-minor and browser-version-revision                        
		}                                                                             
                                                                                
		var detectOS = function() {                                                   
			var platform = navigator.platform;                                           
			if (platform.indexOf('Win') != -1) _sOS = "Windows";                         
    			else if (platform.indexOf('Mac') != -1) _sOS = "Mac OS";                 
    			else if (platform.indexOf('Linux') != -1) _sOS = "Linux";                
			else _sOS = "Unsupported";                                                   
		}                                                                             
                                                                                
		var detectVersion = function(version, browser) {                              
			for (var i = 0, index; i < version.length; i++) {                            
				index = version[i].property.indexOf(version[i].find);                       
				if (index >= 0) {                                                           
					var offset = index + version[i].find.length;                               
					var v = version[i].property.substring(offset);                             
					                                                                           
					// Keep 0-9, a-z, and decimal point characters.	                           
					v = v.split(' ')[0].replace(/[^\d\.a-z]+/g, '');                           
                                                                                
					if (browser == "Safari")                                                   
						return convertVersionSafari(v);                                           
					else if (browser == "OmniWeb")                                             
						return convertVersionOmniWeb(v);                                          
					return v;                                                                  
				}                                                                           
			}                                                                            
			return "Unsupported";                                                        
		}                                                                             
		                                                                              
		// See: http://developer.apple.com/internet/safari/uamatrix.html              
                                                                                
		var convertVersionSafari = function(version) {                                
			var sVersion = version;                                                      
			var nBuild = parseInt(sVersion.split('.')[0]);                               
			if (nBuild >= 419) sVersion = "2.0.4";                                       
			else if (nBuild == 417) sVersion = "2.0.3";                                  
			else if (nBuild == 416) sVersion = "2.0.2";                                  
			else if (nBuild == 412) sVersion = "2.0";                                    
			else if (nBuild == 312) sVersion = "1.3";                                    
			else if (nBuild == 125) sVersion = "1.2";                                    
			else if (nBuild == 100) sVersion = "1.1";                                    
			else if (nBuild == 85) sVersion = "1.0";                                     
			                                                                             
			return sVersion;                                                             
		}                                                                             
                                                                                
		var convertVersionOmniWeb = function(version) {                               
			var sVersion = version;                                                      
			var sBuild = parseInt(sVersion.split('.')[0]);                               
			if (sBuild >= 607) sVersion = "5.5";                                         
			else if (sBuild >= 563) sVersion = "5.1";                                    
			else if (sBuild >= 558) sVersion = "5.0";                                    
			else if (sBuild >= 496) sVersion = "4.5";                                    
			else sVersion = "4";                                                         
			                                                                             
			return sVersion;                                                             
		}                                                                             
                                                                                
		var detectBrowser = function(browser) {                                       
			for (var i = 0; i < browser.length; i++) {                                   
				if (!browser[i].property) return false;                                     
				else if (browser[i].find                                                    
				&& browser[i].property.indexOf(browser[i].find) == -1)                      
					return false;	                                                             
			}                                                                            
			return true;                                                                 
		}                                                                             
                                                                                
		var detect = function() {                                                     
			for (var i = 0; i < _aDefinitions.length; i++) {                             
				if (detectBrowser(_aDefinitions[i].browser)) {                              
					_sBrowserName = _aDefinitions[i].name;                                     
					_sBrowserGroup = _aDefinitions[i].group;                                   
					_sBrowserVersion =                                                         
					  detectVersion(_aDefinitions[i].version,                                  
					    _sBrowserName);                                                        
					                                                                           
					return;                                                                    
				}                                                                           
			}		                                                                          
			_sBrowserName = "Unsupported";                                               
			_sBrowserGroup = "Unsupported";                                              
			_sBrowserVersion = "Unsupported";                                            
		}                                                                             
	}                                                                              
                                                                                
	return constructor;                                                            
})();                                                                           
                                                                                
var CSI_System = new CSI.System();                                              
                                                                                
// Maintain support for deprecated API.                                         
                                                                                
function getBrowser() { return CSI_System.get('browser-name'); }                
function getOS() { return CSI_System.get('operating-system'); }                 
