/**                                                                             
 * Set of utilities to capture and map 3270 key events.                         
 *                                                                              
 * Copyright 2005-2009, CSI International                                       
 * All rights reserved.                                                         
 *                                                                              
 * KEYCP3270.js                                                                 
 * 20050804 P. McClain	Initial version.                                         
 * 20070912 P. McClain	Modified the constraints on supported                    
 *			 	browsers to accomodate their future releases.                            
 * 20090916 P. McClain	Updated the contraints list to test for                  
 *				browsers to be excluded.                                                  
 *                                                                              
 */                                                                             
                                                                                
//--+----1----+----2----+----3----+----4----+----5----+----6----+----7----+----8
                                                                                
var capture3270 = true;                                                         
                                                                                
/*                                                                              
 * Define capture property for 3270 keys.                                       
 *                                                                              
 * param key Key for cookie value.                                              
 * param capture Flag indicates whether keys will be captured.                  
 * param useCookies Flag indicates whether to save value as a cookie.           
 *                                                                              
 * return Capture 3270 keys property.                                           
 */                                                                             
                                                                                
function setCapture3270(key, capture, useCookies) {                             
	                                                                               
    if (useCookies) {                                                           
    	if (capture == true)                                                       
            setCookie(key, "enabled");                                          
	else                                                                           
	    setCookie(key, "disabled");                                                
    }                                                                           
                                                                                
    // Handle suppressing F1 - Internet Explorer Help.                          
                                                                                
    if (capture == true)                                                        
	document.onhelp = function() { return false; }                                 
    else                                                                        
	document.onhelp = null;                                                        
	                                                                               
    capture3270 = capture;                                                      
}                                                                               
                                                                                
/*                                                                              
 * Request the capture 3270 keys property.                                      
 *                                                                              
 * param key Key for cookie value.                                              
 * param useCookies Indicates whether to search for value from a cookie.        
 *                                                                              
 * return Capture 3270 keys property.                                           
 */                                                                             
                                                                                
function getCapture3270(key, useCookies) {                                      
    if (useCookies) {                                                           
    	var capture = getCookie(key);                                              
                                                                                
    	if (capture == null) { // cookie or key does not exist.                    
            setCapture3270(true);                                               
            capture3270 = true;                                                 
	} else if (capture == "enabled")                                               
	    capture3270 = true;                                                        
    	else                                                                       
            capture3270 = false;                                                
    }                                                                           
                                                                                
    if (capture3270 == true)                                                    
    	if (document.onhelp == null) document.onhelp = function() {                
          return false;                                                         
      }                                                                         
    else                                                                        
 	if (document.onhelp != null) document.onhelp = null;                          
                                                                                
    return capture3270;                                                         
}                                                                               
                                                                                
/*                                                                              
 * Cancel propagation of key event.  The key string is forwarded to the caller  
 * using the function callback "send(string)".                                  
 *                                                                              
 * param key Trapped key.                                                       
 * param event Key event to suppress.                                           
 *                                                                              
 * return Always false.                                                         
 */                                                                             
                                                                                
function trapped(key, event) {                                                  
    if (event == null) { // Windows Internet Explorer                           
	window.event.keyCode = 300; // Remap key code to unused value.                 
      window.event.returnValue = false;                                         
    } else {                                                                    
	event.stopPropagation();                                                       
    	event.preventDefault();                                                    
    }     	                                                                     
	                                                                               
    send(key);                                                                  
                                                                                
    return false;                                                               
}                                                                               
                                                                                
/*                                                                              
 * Handler for 3270 (F1 - F24 and <enter>) key events.                          
 *                                                                              
 * param event Key event to inspect.                                            
 */                                                                             
                                                                                
function keyPressed(event) {                                                    
    if (capture3270 == false)                                                   
	return true;                                                                   
                                                                                
    e = (event == null) ? window.event /* Windows Internet Explorer */ : event; 
                                                                                
    code = e.keyCode;                                                           
                                                                                
    // Trap enter key.                                                          
                                                                                
    if (code == 13)                                                             
	return trapped("ENT", event);                                                  
                                                                                
    // Trap function keys F1 - F24.                                             
	                                                                               
    else if (code >= 112 && code <= 123) {                                      
	if (e.shiftKey) {                                                              
	    if (code == 112)      return trapped("P13", event);                        
	    else if (code == 113) return trapped("P14", event);                        
	    else if (code == 114) return trapped("P15", event);                        
	    else if (code == 115) return trapped("P16", event);                        
	    else if (code == 116) return trapped("P17", event);		                      
	    else if (code == 117) return trapped("P18", event);                        
	    else if (code == 118) return trapped("P19", event);	                       
	    else if (code == 119) return trapped("P20", event);                        
	    else if (code == 120) return trapped("P21", event);                        
	    else if (code == 121) return trapped("P22", event);                        
	    else if (code == 122) return trapped("P23", event);                        
	    else if (code == 123) return trapped("P24", event);                        
    	} else {                                                                   
            if (code == 112)    return trapped("P01", event);                   
	    else if (code == 113) return trapped("P02", event);                        
	    else if (code == 114) return trapped("P03", event);                        
	    else if (code == 115) return trapped("P04", event);                        
	    else if (code == 116) return trapped("P05", event);		                      
	    else if (code == 117) return trapped("P06", event);                        
	    else if (code == 118) return trapped("P07", event);	                       
	    else if (code == 119) return trapped("P08", event);                        
	    else if (code == 120) return trapped("P09", event);                        
	    else if (code == 121) return trapped("P10", event);                        
	    else if (code == 122) return trapped("P11", event);                        
	    else if (code == 123) return trapped("P12", event);                        
    	}                                                                          
    }                                                                           
                                                                                
    return true;                                                                
}                                                                               
                                                                                
/**                                                                             
 * Determines whether 3270 key trapping is supported.  The cached value is      
 * used for any subsequent request.                                             
 *                                                                              
 * return true if supported; false otherwise;                                   
 */                                                                             
                                                                                
function isSupported() {                                                        
    	if (typeof isSupported.mode3270 == 'undefined')                            
		isSupported.mode3270 = null;                                                  
                                                                                
    	if (isSupported.mode3270 != null)                                          
		return isSupported.mode3270;                                                  
                                                                                
	var os = CSI_System.get('operating-system');                                   
	var browser = CSI_System.get('browser-name');                                  
	var group = CSI_System.get('browser-group');                                   
	var major = CSI_System.get('browser-version-major');                           
    	                                                                           
	isSupported.mode3270 = true;                                                   
                                                                                
	if (browser == "Opera" && major < 9)                                           
		isSupported.mode3270 = false;                                                 
	else if (browser == "Internet Explorer") {                                     
		if (os == "Windows" && major < 6)                                             
			isSupported.mode3270 = false;                                                
		else if (os == "Mac OS" && major < 5)                                         
			isSupported.mode3270 = false;                                                
	}                                                                              
                                                                                
    	return isSupported.mode3270;                                               
}                                                                               
